@@ -1,6 +1,6 @@
 package Statocles::Command;
 # ABSTRACT: The statocles command-line interface
-$Statocles::Command::VERSION = '0.016';
+$Statocles::Command::VERSION = '0.017';
 use Statocles::Class;
 use Getopt::Long qw( GetOptionsFromArray );
 use Pod::Usage::Return qw( pod2usage );
@@ -55,6 +55,17 @@ sub main {
             }
             return 0;
         }
+        elsif ( $method eq 'daemon' ) {
+            require Mojo::Server::Daemon;
+            my $daemon = Mojo::Server::Daemon->new(
+                silent => 1,
+                app => Statocles::Command::_MOJOAPP->new(
+                    site => $cmd->site,
+                ),
+            );
+            print "Listening on " . $daemon->listen->[0] . "\n";
+            $daemon->run;
+        }
     }
     else {
         my $app_name = $argv[0];
@@ -64,6 +75,23 @@ sub main {
     return 0;
 }
 
+package Statocles::Command::_MOJOAPP;
+$Statocles::Command::_MOJOAPP::VERSION = '0.017';
+use Mojo::Base 'Mojolicious';
+has 'site';
+
+sub startup {
+    my ( $self ) = @_;
+    $self->routes->get( '/', sub { $_[0]->redirect_to( '/index.html' ) } );
+    unshift @{ $self->static->paths },
+        $self->site->build_store->path,
+        # Add the deploy store for non-Statocles content
+        # This won't work in certain situations, like a Git repo on another branch, but
+        # this is convenience until we can track image directories and other non-generated
+        # content.
+        $self->site->deploy_store->path;
+}
+
 1;
 
 __END__
@@ -76,7 +104,7 @@ Statocles::Command - The statocles command-line interface
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 SYNOPSIS
 
